/*
 * Passes through vertices for rendering standard layers. Projective texturing is used to apply the
 * board texture.
 */

attribute vec4 positionAttribute;

uniform mat4 modelMatrix;
uniform mat4 projectionMatrix;
uniform mat3 perspectiveTextureMatrix;

varying vec3 textureCoordinate;

void main() {
    // Multiply the quad vertex by the perspective matrix that maps the quad into a normalized 0-1
    // range along X and Y. The perspective divide is then done in the fragment shader to get the
    // final texture coordinate.
    textureCoordinate = perspectiveTextureMatrix * vec3(positionAttribute.xy, 1.0);

    gl_Position = projectionMatrix * modelMatrix * vec4(positionAttribute.xy, 0.0, 1.0);
}
