/*
 * Renders the image texture with its assocated mask, tint color, and rounded corners.
 */

precision mediump float;

uniform sampler2D mask;
uniform vec2 textureScale;
uniform vec2 textureOffset;
uniform vec4 maskColor;
varying vec2 rectCoordinate;

void main()
{
    // Texture coordinate
    vec2 textureCoordinate = rectCoordinate * textureScale + textureOffset;
    // Discard samples that lie outside the texture
    if (textureCoordinate.x < 0.0 || textureCoordinate.y < 0.0 ||
        textureCoordinate.x > 1.0 || textureCoordinate.y > 1.0) {
        discard;
    }
    // Sample the main image and set its alpha to the value in the mask image
    gl_FragColor = vec4(maskColor.rgb, texture2D(mask, textureCoordinate).r * maskColor.a);
}
